import React, { useState, useCallback, useEffect, useMemo } from "react";
import style from "./index.module.css";
import MyDialog from "../../mui/Dialog";
import { useStores } from "@/store";
import { observer } from "mobx-react-lite";
import { toJS } from "mobx";
import CloudEController from "@/api/fileserver/CloudEController";
import MyTreeView from "@/components/mui/MyTreeView";
import classNames from "classnames";
import bigFolderIcon from "@/assets/project/bigFolderIcon.svg";
import Table from "@/components/Material.Ui/Table";
import noFile from "@/assets/project/noFile.svg";
import folderIcon from "@/assets/project/folderIcon.svg";
import SearchIcon from "@mui/icons-material/Search";
import dataSetIcon from "@/assets/project/dataSetIcon.svg";
import fileIcon from "@/assets/project/fileIcon.svg";
import OutlinedInput from "@mui/material/OutlinedInput";
import useMyRequest from "@/hooks/useMyRequest";
import { getDataFind } from "@/api/project_api";
import { storageUnitFromB } from "@/utils/util";
import classnames from "classnames";
import _ from "lodash";
import moment from "moment";

type FileSelectProps = {
	open: boolean;
	onConfirm: any;
	onClose: any;
	type?: "file" | "dataset" | "path"; // file 文件选择 dataset数据集选择  path文件夹选择
};

const FileSelect = observer((props: FileSelectProps) => {
	const { onConfirm, type = "path" } = props;
	const { currentProjectStore } = useStores();
	const projectId = toJS(currentProjectStore.currentProjectInfo.id);
	const fileToken = toJS(currentProjectStore.currentProjectInfo.filetoken);
	const [path, setPath] = useState<String>("/");
	// 防止用户连续点击文件夹造成路径显示错误
	const [debounce, setDebounce] = useState(false);
	// 文件夹、文件列表
	const [list, setList] = useState<any>([]);
	// 数据集列表  不带文件
	const [dataSetList, setDataSetList] = useState<any>([]);
	const [keyWord, setKeyWord] = useState("");

	const fileSelectOnConfirm = () => {
		onConfirm(path);
	};

	// 搜索值改变
	const handleKeyWordChange = (e: any) => {
		if (e.target.value.length > 30) {
			return;
		}
		setKeyWord(e.target.value);
	};

	// 按回车搜索
	const handleKeyWordChangeKeyUp = (e: any) => {
		if (e.keyCode === 13) {
			// searchFileList();
			// getDataSetListSearch();
		}
	};

	// 文件夹下钻
	const handleViewFolders = (item: any) => {
		if (debounce) {
			return;
		} else {
			setDebounce(true);
			if (path === "/") {
				setPath(`/${item.name}`);
			} else {
				setPath(`${path}/${item.name}`);
			}
		}
	};

	// table配置
	const renderName = (item: any) => {
		if (item.type === "directory") {
			return (
				<span
					className={classnames({
						[style.folderIconBox]: true,
						[style.folderPointer]: true,
					})}
					onClick={() => handleViewFolders(item)}
				>
					<img className={style.folderIcon} src={folderIcon} alt="" />
					{item.name}
				</span>
			);
		} else if (item.type === "dataSet") {
			return (
				<span className={style.folderIconBox}>
					<img className={style.folderIcon} src={dataSetIcon} alt="" />
					{item.name}
				</span>
			);
		} else {
			return (
				<span className={style.folderIconBox}>
					<img className={style.folderIcon} src={fileIcon} alt="" />
					{item.name}
				</span>
			);
		}
	};

	// table配置
	const renderSize = (item: any) => {
		if (item.type === "dataSet") {
			return `${item.size}条`;
		}
		return `${item.size ? storageUnitFromB(Number(item.size)) : "-"}`;
	};

	// table配置
	const renderMtime = (item: any) => {
		return String(moment(item.mtime).format("YYYY-MM-DD HH:mm:ss"));
	};

	// table配置
	const versionsHeadCells = [
		{ id: "name", numeric: false, label: "名称", width: "30%" },
		{ id: "size", numeric: false, label: "大小", width: "20%", sort: true },
		{
			id: "mtime",
			numeric: false,
			label: "创建时间",
			width: "30%",
			sort: true,
		},
	];

	// 列表展示的数据
	const showList = useMemo(() => {
		return [...list, ...dataSetList];
	}, [list, dataSetList]);

	// 前端展示的文件路径
	const showPath = useMemo(() => {
		if (path === "/") {
			return <span className={style.showPathSpan}>ProjectData</span>;
		} else {
			const pathArr = path.split("/");
			if (pathArr.length <= 4) {
				return pathArr.map((item, index) => {
					return (
						<span
							key={index}
							onClick={() =>
								setPath(
									pathArr.slice(0, index + 1).join("/") === ""
										? "/"
										: pathArr.slice(0, index + 1).join("/")
								)
							}
							className={classnames({
								[style.showPathSpan]: true,
								[style.showPathSpanActive]: index === pathArr.length - 1,
							})}
						>
							{index === 0 ? "ProjectData" : item}{" "}
							{index === pathArr.length - 1 ? null : (
								<i className={style.showPathI}>{">"}</i>
							)}
						</span>
					);
				});
			} else {
				return pathArr.map((item, index) => {
					return (
						<span
							key={index}
							onClick={() => {
								if (index === 1) {
									return;
								}
								setPath(
									pathArr.slice(0, index + 1).join("/") === ""
										? "/"
										: pathArr.slice(0, index + 1).join("/")
								);
							}}
							className={classnames({
								[style.showPathSpan]: true,
								[style.showPathSpanActive]: index === pathArr.length - 1,
							})}
						>
							{index === 0
								? "ProjectData"
								: index > pathArr.length - 4
								? item
								: ""}
							{/* && index > pathArr.length - 4 */}
							{index === pathArr.length - 1 ||
							(index <= pathArr.length - 4 && index > 0) ? null : (
								<i className={style.showPathI}>{">"}</i>
							)}
							{index === 1 && "..."}
							{index === 1 && <i className={style.showPathI}>{">"}</i>}
						</span>
					);
				});
			}
		}
	}, [path]);

	return (
		<MyDialog
			open={props.open}
			onClose={props.onClose}
			onConfirm={fileSelectOnConfirm}
			title="文件选择器"
		>
			<div className={style.FSBox}>
				<div className={style.FSTop}>
					<div className={style.FSPath}>{showPath}</div>
					<div className={style.FSKeyWord}>
						<OutlinedInput
							value={keyWord}
							onChange={handleKeyWordChange}
							placeholder="输入关键词搜索"
							size="small"
							sx={{ width: 240, height: 32 }}
							endAdornment={<SearchIcon style={{ color: "#8A9099" }} />}
							onKeyUp={handleKeyWordChangeKeyUp}
						/>
					</div>
				</div>
				<Table
					footer={false}
					rowHover={true}
					nopadding={true}
					stickyheader={true}
					headCells={versionsHeadCells}
					rowsPerPage={"99"}
					rows={showList.map((item: any, index: number) => ({
						...item,
						id: `name=${item.name}&index=${index}`,
						name: renderName(item),
						size: renderSize(item),
						mtime: renderMtime(item),
					}))}
				></Table>
				{showList.length === 0 && (
					<div className={style.noDataBox}>
						<img className={style.noDataImg} src={noFile} alt="" />
						<span className={style.noDataText}>暂未开启模板</span>
					</div>
				)}
			</div>
		</MyDialog>
	);
});

export default FileSelect;
